pub enum ElementStatus<M> {
Dequeued,
Dropped(M),
}
The status of an element inserted into a diem_channel. If the element is successfully
dequeued, ElementStatus::Dequeued is sent to the sender. If it is dropped
ElementStatus::Dropped is sent to the sender along with the dropped element.
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.