Struct channel::diem_channel::Config [−][src]
pub struct Config {
pub queue_style: QueueStyle,
pub max_capacity: usize,
pub counters: Option<&'static IntCounterVec>,
}Expand description
Configuration for a new diem_channel queue.
Fields
queue_style: QueueStylemax_capacity: usizecounters: Option<&'static IntCounterVec>Implementations
The diem_channel has a “sub-queue” per key. The max_capacity controls
the capacity of each “sub-queue”; when the queues exceed the max
capacity the messages will be dropped according to the queue style/eviction
policy.
The queue’s push/pop and eviction behavior. Defaults to FIFO.
Optional prometheus counters for this queue, which keep track of items in the queue and # dropped items. Defaults to no counters.