Struct channel::diem_channel::Sender[][src]

pub struct Sender<K: Eq + Hash + Clone, M> { /* fields omitted */ }
The sending end of the diem_channel.

Implementations

This adds the message into the internal queue data structure. This is a synchronous call.

Same as push, but this function also accepts a oneshot::Sender over which the sender can be notified when the message eventually gets delivered or dropped.