Struct channel::diem_channel::Sender [−][src]
The sending end of the diem_channel.
Implementations
This adds the message into the internal queue data structure. This is a synchronous call.
pub fn push_with_feedback(
&self,
key: K,
message: M,
status_ch: Option<Sender<ElementStatus<M>>>
) -> Result<()>
pub fn push_with_feedback(
&self,
key: K,
message: M,
status_ch: Option<Sender<ElementStatus<M>>>
) -> Result<()>
Same as push, but this function also accepts a oneshot::Sender over which the sender can
be notified when the message eventually gets delivered or dropped.